# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.fault_domains_api import FaultDomainsApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestFaultDomainsApi(unittest.TestCase):
    """FaultDomainsApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.fault_domains_api.FaultDomainsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_node(self):
        """Test case for add_node

        """
        pass

    def test_get_fault_domain_details(self):
        """Test case for get_fault_domain_details

        """
        pass

    def test_get_fault_domains(self):
        """Test case for get_fault_domains

        """
        pass

    def test_get_inventory(self):
        """Test case for get_inventory

        """
        pass


if __name__ == '__main__':
    unittest.main()
