# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.cloud_users_api import CloudUsersApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestCloudUsersApi(unittest.TestCase):
    """CloudUsersApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.cloud_users_api.CloudUsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_allocate_vlan(self):
        """Test case for allocate_vlan

        """
        pass

    def test_delete_tenant(self):
        """Test case for delete_tenant

        """
        pass

    def test_get_tenant(self):
        """Test case for get_tenant

        """
        pass

    def test_get_tenants(self):
        """Test case for get_tenants

        """
        pass

    def test_list_cloud_user_comments(self):
        """Test case for list_cloud_user_comments

        """
        pass

    def test_list_cloud_vlans(self):
        """Test case for list_cloud_vlans

        """
        pass


if __name__ == '__main__':
    unittest.main()
