# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20055PasswordStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'password_experation_limit': 'bool',
        'password_history': 'int'
    }

    attribute_map = {
        'password_experation_limit': 'password_experation_limit',
        'password_history': 'password_history'
    }

    def __init__(self, password_experation_limit=None, password_history=None, _configuration=None):  # noqa: E501
        """InlineResponse20055PasswordStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._password_experation_limit = None
        self._password_history = None
        self.discriminator = None

        if password_experation_limit is not None:
            self.password_experation_limit = password_experation_limit
        if password_history is not None:
            self.password_history = password_history

    @property
    def password_experation_limit(self):
        """Gets the password_experation_limit of this InlineResponse20055PasswordStatus.  # noqa: E501


        :return: The password_experation_limit of this InlineResponse20055PasswordStatus.  # noqa: E501
        :rtype: bool
        """
        return self._password_experation_limit

    @password_experation_limit.setter
    def password_experation_limit(self, password_experation_limit):
        """Sets the password_experation_limit of this InlineResponse20055PasswordStatus.


        :param password_experation_limit: The password_experation_limit of this InlineResponse20055PasswordStatus.  # noqa: E501
        :type: bool
        """

        self._password_experation_limit = password_experation_limit

    @property
    def password_history(self):
        """Gets the password_history of this InlineResponse20055PasswordStatus.  # noqa: E501


        :return: The password_history of this InlineResponse20055PasswordStatus.  # noqa: E501
        :rtype: int
        """
        return self._password_history

    @password_history.setter
    def password_history(self, password_history):
        """Sets the password_history of this InlineResponse20055PasswordStatus.


        :param password_history: The password_history of this InlineResponse20055PasswordStatus.  # noqa: E501
        :type: int
        """

        self._password_history = password_history

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20055PasswordStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20055PasswordStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20055PasswordStatus):
            return True

        return self.to_dict() != other.to_dict()
