# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20048ResponseUsageReportHeader(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'zios_name': 'str',
        'zios_display_name': 'str',
        'upload_rate_per_gb': 'float',
        'policy_capacity_usage_cost_gbmonth': 'InlineResponse20048ResponseUsageReportHeaderPolicyCapacityUsageCostGbmonth',
        'download_rate_per_gb': 'float',
        'billing_unit': 'str',
        'total_usage_charges': 'float',
        'reporting_interval': 'InlineResponse20048ResponseUsageReportHeaderReportingInterval',
        'zios_url': 'str'
    }

    attribute_map = {
        'zios_name': 'zios_name',
        'zios_display_name': 'zios_display_name',
        'upload_rate_per_gb': 'upload_rate_per_gb',
        'policy_capacity_usage_cost_gbmonth': 'policy_capacity_usage_cost_gbmonth',
        'download_rate_per_gb': 'download_rate_per_gb',
        'billing_unit': 'billing_unit',
        'total_usage_charges': 'total_usage_charges',
        'reporting_interval': 'reporting_interval',
        'zios_url': 'zios_url'
    }

    def __init__(self, zios_name=None, zios_display_name=None, upload_rate_per_gb=None, policy_capacity_usage_cost_gbmonth=None, download_rate_per_gb=None, billing_unit=None, total_usage_charges=None, reporting_interval=None, zios_url=None, _configuration=None):  # noqa: E501
        """InlineResponse20048ResponseUsageReportHeader - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._zios_name = None
        self._zios_display_name = None
        self._upload_rate_per_gb = None
        self._policy_capacity_usage_cost_gbmonth = None
        self._download_rate_per_gb = None
        self._billing_unit = None
        self._total_usage_charges = None
        self._reporting_interval = None
        self._zios_url = None
        self.discriminator = None

        if zios_name is not None:
            self.zios_name = zios_name
        if zios_display_name is not None:
            self.zios_display_name = zios_display_name
        if upload_rate_per_gb is not None:
            self.upload_rate_per_gb = upload_rate_per_gb
        if policy_capacity_usage_cost_gbmonth is not None:
            self.policy_capacity_usage_cost_gbmonth = policy_capacity_usage_cost_gbmonth
        if download_rate_per_gb is not None:
            self.download_rate_per_gb = download_rate_per_gb
        if billing_unit is not None:
            self.billing_unit = billing_unit
        if total_usage_charges is not None:
            self.total_usage_charges = total_usage_charges
        if reporting_interval is not None:
            self.reporting_interval = reporting_interval
        if zios_url is not None:
            self.zios_url = zios_url

    @property
    def zios_name(self):
        """Gets the zios_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The zios_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: str
        """
        return self._zios_name

    @zios_name.setter
    def zios_name(self, zios_name):
        """Sets the zios_name of this InlineResponse20048ResponseUsageReportHeader.


        :param zios_name: The zios_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: str
        """

        self._zios_name = zios_name

    @property
    def zios_display_name(self):
        """Gets the zios_display_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The zios_display_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: str
        """
        return self._zios_display_name

    @zios_display_name.setter
    def zios_display_name(self, zios_display_name):
        """Sets the zios_display_name of this InlineResponse20048ResponseUsageReportHeader.


        :param zios_display_name: The zios_display_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: str
        """

        self._zios_display_name = zios_display_name

    @property
    def upload_rate_per_gb(self):
        """Gets the upload_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The upload_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: float
        """
        return self._upload_rate_per_gb

    @upload_rate_per_gb.setter
    def upload_rate_per_gb(self, upload_rate_per_gb):
        """Sets the upload_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.


        :param upload_rate_per_gb: The upload_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: float
        """

        self._upload_rate_per_gb = upload_rate_per_gb

    @property
    def policy_capacity_usage_cost_gbmonth(self):
        """Gets the policy_capacity_usage_cost_gbmonth of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The policy_capacity_usage_cost_gbmonth of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: InlineResponse20048ResponseUsageReportHeaderPolicyCapacityUsageCostGbmonth
        """
        return self._policy_capacity_usage_cost_gbmonth

    @policy_capacity_usage_cost_gbmonth.setter
    def policy_capacity_usage_cost_gbmonth(self, policy_capacity_usage_cost_gbmonth):
        """Sets the policy_capacity_usage_cost_gbmonth of this InlineResponse20048ResponseUsageReportHeader.


        :param policy_capacity_usage_cost_gbmonth: The policy_capacity_usage_cost_gbmonth of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: InlineResponse20048ResponseUsageReportHeaderPolicyCapacityUsageCostGbmonth
        """

        self._policy_capacity_usage_cost_gbmonth = policy_capacity_usage_cost_gbmonth

    @property
    def download_rate_per_gb(self):
        """Gets the download_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The download_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: float
        """
        return self._download_rate_per_gb

    @download_rate_per_gb.setter
    def download_rate_per_gb(self, download_rate_per_gb):
        """Sets the download_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.


        :param download_rate_per_gb: The download_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: float
        """

        self._download_rate_per_gb = download_rate_per_gb

    @property
    def billing_unit(self):
        """Gets the billing_unit of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The billing_unit of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: str
        """
        return self._billing_unit

    @billing_unit.setter
    def billing_unit(self, billing_unit):
        """Sets the billing_unit of this InlineResponse20048ResponseUsageReportHeader.


        :param billing_unit: The billing_unit of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: str
        """

        self._billing_unit = billing_unit

    @property
    def total_usage_charges(self):
        """Gets the total_usage_charges of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The total_usage_charges of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: float
        """
        return self._total_usage_charges

    @total_usage_charges.setter
    def total_usage_charges(self, total_usage_charges):
        """Sets the total_usage_charges of this InlineResponse20048ResponseUsageReportHeader.


        :param total_usage_charges: The total_usage_charges of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: float
        """

        self._total_usage_charges = total_usage_charges

    @property
    def reporting_interval(self):
        """Gets the reporting_interval of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The reporting_interval of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: InlineResponse20048ResponseUsageReportHeaderReportingInterval
        """
        return self._reporting_interval

    @reporting_interval.setter
    def reporting_interval(self, reporting_interval):
        """Sets the reporting_interval of this InlineResponse20048ResponseUsageReportHeader.


        :param reporting_interval: The reporting_interval of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: InlineResponse20048ResponseUsageReportHeaderReportingInterval
        """

        self._reporting_interval = reporting_interval

    @property
    def zios_url(self):
        """Gets the zios_url of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The zios_url of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: str
        """
        return self._zios_url

    @zios_url.setter
    def zios_url(self, zios_url):
        """Sets the zios_url of this InlineResponse20048ResponseUsageReportHeader.


        :param zios_url: The zios_url of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: str
        """

        self._zios_url = zios_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20048ResponseUsageReportHeader, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20048ResponseUsageReportHeader):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20048ResponseUsageReportHeader):
            return True

        return self.to_dict() != other.to_dict()
