# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class UpdateVpsaGenericZconfigKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key_name': 'str',
        'key_value': 'str'
    }

    attribute_map = {
        'key_name': 'key_name',
        'key_value': 'key_value'
    }

    def __init__(self, key_name=None, key_value=None, _configuration=None):  # noqa: E501
        """UpdateVpsaGenericZconfigKey - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._key_name = None
        self._key_value = None
        self.discriminator = None

        self.key_name = key_name
        self.key_value = key_value

    @property
    def key_name(self):
        """Gets the key_name of this UpdateVpsaGenericZconfigKey.  # noqa: E501

        Key name  # noqa: E501

        :return: The key_name of this UpdateVpsaGenericZconfigKey.  # noqa: E501
        :rtype: str
        """
        return self._key_name

    @key_name.setter
    def key_name(self, key_name):
        """Sets the key_name of this UpdateVpsaGenericZconfigKey.

        Key name  # noqa: E501

        :param key_name: The key_name of this UpdateVpsaGenericZconfigKey.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and key_name is None:
            raise ValueError("Invalid value for `key_name`, must not be `None`")  # noqa: E501

        self._key_name = key_name

    @property
    def key_value(self):
        """Gets the key_value of this UpdateVpsaGenericZconfigKey.  # noqa: E501

        Key value  # noqa: E501

        :return: The key_value of this UpdateVpsaGenericZconfigKey.  # noqa: E501
        :rtype: str
        """
        return self._key_value

    @key_value.setter
    def key_value(self, key_value):
        """Sets the key_value of this UpdateVpsaGenericZconfigKey.

        Key value  # noqa: E501

        :param key_value: The key_value of this UpdateVpsaGenericZconfigKey.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and key_value is None:
            raise ValueError("Invalid value for `key_value`, must not be `None`")  # noqa: E501

        self._key_value = key_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateVpsaGenericZconfigKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVpsaGenericZconfigKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateVpsaGenericZconfigKey):
            return True

        return self.to_dict() != other.to_dict()
