# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20052ResponseImage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'status': 'str',
        'is_layered': 'str',
        'docker_id': 'str',
        'license_state': 'int',
        'capacity_mb': 'int',
        'repository': 'str',
        'tag': 'str',
        'volume_id': 'int',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'status': 'status',
        'is_layered': 'is_layered',
        'docker_id': 'docker_id',
        'license_state': 'license_state',
        'capacity_mb': 'capacity_mb',
        'repository': 'repository',
        'tag': 'tag',
        'volume_id': 'volume_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, status=None, is_layered=None, docker_id=None, license_state=None, capacity_mb=None, repository=None, tag=None, volume_id=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20052ResponseImage - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._status = None
        self._is_layered = None
        self._docker_id = None
        self._license_state = None
        self._capacity_mb = None
        self._repository = None
        self._tag = None
        self._volume_id = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if status is not None:
            self.status = status
        if is_layered is not None:
            self.is_layered = is_layered
        if docker_id is not None:
            self.docker_id = docker_id
        if license_state is not None:
            self.license_state = license_state
        if capacity_mb is not None:
            self.capacity_mb = capacity_mb
        if repository is not None:
            self.repository = repository
        if tag is not None:
            self.tag = tag
        if volume_id is not None:
            self.volume_id = volume_id
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The name of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20052ResponseImage.


        :param name: The name of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The display_name of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20052ResponseImage.


        :param display_name: The display_name of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def status(self):
        """Gets the status of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The status of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20052ResponseImage.


        :param status: The status of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def is_layered(self):
        """Gets the is_layered of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The is_layered of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._is_layered

    @is_layered.setter
    def is_layered(self, is_layered):
        """Sets the is_layered of this InlineResponse20052ResponseImage.


        :param is_layered: The is_layered of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._is_layered = is_layered

    @property
    def docker_id(self):
        """Gets the docker_id of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The docker_id of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._docker_id

    @docker_id.setter
    def docker_id(self, docker_id):
        """Sets the docker_id of this InlineResponse20052ResponseImage.


        :param docker_id: The docker_id of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._docker_id = docker_id

    @property
    def license_state(self):
        """Gets the license_state of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The license_state of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: int
        """
        return self._license_state

    @license_state.setter
    def license_state(self, license_state):
        """Sets the license_state of this InlineResponse20052ResponseImage.


        :param license_state: The license_state of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: int
        """

        self._license_state = license_state

    @property
    def capacity_mb(self):
        """Gets the capacity_mb of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The capacity_mb of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: int
        """
        return self._capacity_mb

    @capacity_mb.setter
    def capacity_mb(self, capacity_mb):
        """Sets the capacity_mb of this InlineResponse20052ResponseImage.


        :param capacity_mb: The capacity_mb of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: int
        """

        self._capacity_mb = capacity_mb

    @property
    def repository(self):
        """Gets the repository of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The repository of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this InlineResponse20052ResponseImage.


        :param repository: The repository of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._repository = repository

    @property
    def tag(self):
        """Gets the tag of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The tag of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this InlineResponse20052ResponseImage.


        :param tag: The tag of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def volume_id(self):
        """Gets the volume_id of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The volume_id of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: int
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """Sets the volume_id of this InlineResponse20052ResponseImage.


        :param volume_id: The volume_id of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: int
        """

        self._volume_id = volume_id

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The created_at of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20052ResponseImage.


        :param created_at: The created_at of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The modified_at of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20052ResponseImage.


        :param modified_at: The modified_at of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20052ResponseImage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20052ResponseImage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20052ResponseImage):
            return True

        return self.to_dict() != other.to_dict()
