# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200268ResponseUsages(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rd_iops': 'float',
        'rd_bandwidth': 'float',
        'rd_iotime': 'float',
        'rd_max_time': 'int',
        'rd_queue_len': 'int',
        'wrt_iops': 'float',
        'wrt_bandwidth': 'float',
        'wrt_iotime': 'float',
        'wrt_max_time': 'int',
        'wrt_queue_len': 'int',
        'nonrw_iops': 'float',
        'nonrw_bandwidth': 'float',
        'nonrw_iotime': 'float',
        'nonrw_max_time': 'int',
        'nonrw_queue_len': 'int',
        'xcopy_iops': 'float',
        'xcopy_bandwidth': 'float',
        'xcopy_iotime': 'float',
        'xcopy_max_time': 'int',
        'xcopy_queue_len': 'int',
        'other_iops': 'float',
        'other_bandwidth': 'float',
        'other_iotime': 'float',
        'other_max_time': 'int',
        'other_queue_len': 'int',
        'creat_iops': 'float',
        'creat_bandwidth': 'float',
        'creat_iotime': 'float',
        'creat_max_time': 'int',
        'creat_queue_len': 'int',
        'delet_iops': 'float',
        'delet_bandwidth': 'float',
        'delet_iotime': 'float',
        'delet_max_time': 'int',
        'delet_queue_len': 'int',
        'renam_iops': 'float',
        'renam_bandwidth': 'float',
        'renam_iotime': 'float',
        'renam_max_time': 'int',
        'renam_queue_len': 'int',
        'flush_iops': 'float',
        'flush_bandwidth': 'float',
        'flush_iotime': 'float',
        'flush_max_time': 'int',
        'flush_queue_len': 'int',
        'lock_iops': 'float',
        'lock_bandwidth': 'float',
        'lock_iotime': 'float',
        'lock_max_time': 'int',
        'lock_queue_len': 'int',
        'ulock_iops': 'float',
        'ulock_bandwidth': 'float',
        'ulock_iotime': 'float',
        'ulock_max_time': 'int',
        'ulock_queue_len': 'int',
        'geta_iops': 'float',
        'geta_bandwidth': 'float',
        'geta_iotime': 'float',
        'geta_max_time': 'int',
        'geta_queue_len': 'int',
        'seta_iops': 'float',
        'seta_bandwidth': 'float',
        'seta_iotime': 'float',
        'seta_max_time': 'int',
        'seta_queue_len': 'int',
        'rddir_iops': 'float',
        'rddir_bandwidth': 'float',
        'rddir_iotime': 'float',
        'rddir_max_time': 'int',
        'rddir_queue_len': 'int',
        'time': 'str'
    }

    attribute_map = {
        'rd_iops': 'rd_iops',
        'rd_bandwidth': 'rd_bandwidth',
        'rd_iotime': 'rd_iotime',
        'rd_max_time': 'rd_max_time',
        'rd_queue_len': 'rd_queue_len',
        'wrt_iops': 'wrt_iops',
        'wrt_bandwidth': 'wrt_bandwidth',
        'wrt_iotime': 'wrt_iotime',
        'wrt_max_time': 'wrt_max_time',
        'wrt_queue_len': 'wrt_queue_len',
        'nonrw_iops': 'nonrw_iops',
        'nonrw_bandwidth': 'nonrw_bandwidth',
        'nonrw_iotime': 'nonrw_iotime',
        'nonrw_max_time': 'nonrw_max_time',
        'nonrw_queue_len': 'nonrw_queue_len',
        'xcopy_iops': 'xcopy_iops',
        'xcopy_bandwidth': 'xcopy_bandwidth',
        'xcopy_iotime': 'xcopy_iotime',
        'xcopy_max_time': 'xcopy_max_time',
        'xcopy_queue_len': 'xcopy_queue_len',
        'other_iops': 'other_iops',
        'other_bandwidth': 'other_bandwidth',
        'other_iotime': 'other_iotime',
        'other_max_time': 'other_max_time',
        'other_queue_len': 'other_queue_len',
        'creat_iops': 'creat_iops',
        'creat_bandwidth': 'creat_bandwidth',
        'creat_iotime': 'creat_iotime',
        'creat_max_time': 'creat_max_time',
        'creat_queue_len': 'creat_queue_len',
        'delet_iops': 'delet_iops',
        'delet_bandwidth': 'delet_bandwidth',
        'delet_iotime': 'delet_iotime',
        'delet_max_time': 'delet_max_time',
        'delet_queue_len': 'delet_queue_len',
        'renam_iops': 'renam_iops',
        'renam_bandwidth': 'renam_bandwidth',
        'renam_iotime': 'renam_iotime',
        'renam_max_time': 'renam_max_time',
        'renam_queue_len': 'renam_queue_len',
        'flush_iops': 'flush_iops',
        'flush_bandwidth': 'flush_bandwidth',
        'flush_iotime': 'flush_iotime',
        'flush_max_time': 'flush_max_time',
        'flush_queue_len': 'flush_queue_len',
        'lock_iops': 'lock_iops',
        'lock_bandwidth': 'lock_bandwidth',
        'lock_iotime': 'lock_iotime',
        'lock_max_time': 'lock_max_time',
        'lock_queue_len': 'lock_queue_len',
        'ulock_iops': 'ulock_iops',
        'ulock_bandwidth': 'ulock_bandwidth',
        'ulock_iotime': 'ulock_iotime',
        'ulock_max_time': 'ulock_max_time',
        'ulock_queue_len': 'ulock_queue_len',
        'geta_iops': 'geta_iops',
        'geta_bandwidth': 'geta_bandwidth',
        'geta_iotime': 'geta_iotime',
        'geta_max_time': 'geta_max_time',
        'geta_queue_len': 'geta_queue_len',
        'seta_iops': 'seta_iops',
        'seta_bandwidth': 'seta_bandwidth',
        'seta_iotime': 'seta_iotime',
        'seta_max_time': 'seta_max_time',
        'seta_queue_len': 'seta_queue_len',
        'rddir_iops': 'rddir_iops',
        'rddir_bandwidth': 'rddir_bandwidth',
        'rddir_iotime': 'rddir_iotime',
        'rddir_max_time': 'rddir_max_time',
        'rddir_queue_len': 'rddir_queue_len',
        'time': 'time'
    }

    def __init__(self, rd_iops=None, rd_bandwidth=None, rd_iotime=None, rd_max_time=None, rd_queue_len=None, wrt_iops=None, wrt_bandwidth=None, wrt_iotime=None, wrt_max_time=None, wrt_queue_len=None, nonrw_iops=None, nonrw_bandwidth=None, nonrw_iotime=None, nonrw_max_time=None, nonrw_queue_len=None, xcopy_iops=None, xcopy_bandwidth=None, xcopy_iotime=None, xcopy_max_time=None, xcopy_queue_len=None, other_iops=None, other_bandwidth=None, other_iotime=None, other_max_time=None, other_queue_len=None, creat_iops=None, creat_bandwidth=None, creat_iotime=None, creat_max_time=None, creat_queue_len=None, delet_iops=None, delet_bandwidth=None, delet_iotime=None, delet_max_time=None, delet_queue_len=None, renam_iops=None, renam_bandwidth=None, renam_iotime=None, renam_max_time=None, renam_queue_len=None, flush_iops=None, flush_bandwidth=None, flush_iotime=None, flush_max_time=None, flush_queue_len=None, lock_iops=None, lock_bandwidth=None, lock_iotime=None, lock_max_time=None, lock_queue_len=None, ulock_iops=None, ulock_bandwidth=None, ulock_iotime=None, ulock_max_time=None, ulock_queue_len=None, geta_iops=None, geta_bandwidth=None, geta_iotime=None, geta_max_time=None, geta_queue_len=None, seta_iops=None, seta_bandwidth=None, seta_iotime=None, seta_max_time=None, seta_queue_len=None, rddir_iops=None, rddir_bandwidth=None, rddir_iotime=None, rddir_max_time=None, rddir_queue_len=None, time=None, _configuration=None):  # noqa: E501
        """InlineResponse200268ResponseUsages - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._rd_iops = None
        self._rd_bandwidth = None
        self._rd_iotime = None
        self._rd_max_time = None
        self._rd_queue_len = None
        self._wrt_iops = None
        self._wrt_bandwidth = None
        self._wrt_iotime = None
        self._wrt_max_time = None
        self._wrt_queue_len = None
        self._nonrw_iops = None
        self._nonrw_bandwidth = None
        self._nonrw_iotime = None
        self._nonrw_max_time = None
        self._nonrw_queue_len = None
        self._xcopy_iops = None
        self._xcopy_bandwidth = None
        self._xcopy_iotime = None
        self._xcopy_max_time = None
        self._xcopy_queue_len = None
        self._other_iops = None
        self._other_bandwidth = None
        self._other_iotime = None
        self._other_max_time = None
        self._other_queue_len = None
        self._creat_iops = None
        self._creat_bandwidth = None
        self._creat_iotime = None
        self._creat_max_time = None
        self._creat_queue_len = None
        self._delet_iops = None
        self._delet_bandwidth = None
        self._delet_iotime = None
        self._delet_max_time = None
        self._delet_queue_len = None
        self._renam_iops = None
        self._renam_bandwidth = None
        self._renam_iotime = None
        self._renam_max_time = None
        self._renam_queue_len = None
        self._flush_iops = None
        self._flush_bandwidth = None
        self._flush_iotime = None
        self._flush_max_time = None
        self._flush_queue_len = None
        self._lock_iops = None
        self._lock_bandwidth = None
        self._lock_iotime = None
        self._lock_max_time = None
        self._lock_queue_len = None
        self._ulock_iops = None
        self._ulock_bandwidth = None
        self._ulock_iotime = None
        self._ulock_max_time = None
        self._ulock_queue_len = None
        self._geta_iops = None
        self._geta_bandwidth = None
        self._geta_iotime = None
        self._geta_max_time = None
        self._geta_queue_len = None
        self._seta_iops = None
        self._seta_bandwidth = None
        self._seta_iotime = None
        self._seta_max_time = None
        self._seta_queue_len = None
        self._rddir_iops = None
        self._rddir_bandwidth = None
        self._rddir_iotime = None
        self._rddir_max_time = None
        self._rddir_queue_len = None
        self._time = None
        self.discriminator = None

        if rd_iops is not None:
            self.rd_iops = rd_iops
        if rd_bandwidth is not None:
            self.rd_bandwidth = rd_bandwidth
        if rd_iotime is not None:
            self.rd_iotime = rd_iotime
        if rd_max_time is not None:
            self.rd_max_time = rd_max_time
        if rd_queue_len is not None:
            self.rd_queue_len = rd_queue_len
        if wrt_iops is not None:
            self.wrt_iops = wrt_iops
        if wrt_bandwidth is not None:
            self.wrt_bandwidth = wrt_bandwidth
        if wrt_iotime is not None:
            self.wrt_iotime = wrt_iotime
        if wrt_max_time is not None:
            self.wrt_max_time = wrt_max_time
        if wrt_queue_len is not None:
            self.wrt_queue_len = wrt_queue_len
        if nonrw_iops is not None:
            self.nonrw_iops = nonrw_iops
        if nonrw_bandwidth is not None:
            self.nonrw_bandwidth = nonrw_bandwidth
        if nonrw_iotime is not None:
            self.nonrw_iotime = nonrw_iotime
        if nonrw_max_time is not None:
            self.nonrw_max_time = nonrw_max_time
        if nonrw_queue_len is not None:
            self.nonrw_queue_len = nonrw_queue_len
        if xcopy_iops is not None:
            self.xcopy_iops = xcopy_iops
        if xcopy_bandwidth is not None:
            self.xcopy_bandwidth = xcopy_bandwidth
        if xcopy_iotime is not None:
            self.xcopy_iotime = xcopy_iotime
        if xcopy_max_time is not None:
            self.xcopy_max_time = xcopy_max_time
        if xcopy_queue_len is not None:
            self.xcopy_queue_len = xcopy_queue_len
        if other_iops is not None:
            self.other_iops = other_iops
        if other_bandwidth is not None:
            self.other_bandwidth = other_bandwidth
        if other_iotime is not None:
            self.other_iotime = other_iotime
        if other_max_time is not None:
            self.other_max_time = other_max_time
        if other_queue_len is not None:
            self.other_queue_len = other_queue_len
        if creat_iops is not None:
            self.creat_iops = creat_iops
        if creat_bandwidth is not None:
            self.creat_bandwidth = creat_bandwidth
        if creat_iotime is not None:
            self.creat_iotime = creat_iotime
        if creat_max_time is not None:
            self.creat_max_time = creat_max_time
        if creat_queue_len is not None:
            self.creat_queue_len = creat_queue_len
        if delet_iops is not None:
            self.delet_iops = delet_iops
        if delet_bandwidth is not None:
            self.delet_bandwidth = delet_bandwidth
        if delet_iotime is not None:
            self.delet_iotime = delet_iotime
        if delet_max_time is not None:
            self.delet_max_time = delet_max_time
        if delet_queue_len is not None:
            self.delet_queue_len = delet_queue_len
        if renam_iops is not None:
            self.renam_iops = renam_iops
        if renam_bandwidth is not None:
            self.renam_bandwidth = renam_bandwidth
        if renam_iotime is not None:
            self.renam_iotime = renam_iotime
        if renam_max_time is not None:
            self.renam_max_time = renam_max_time
        if renam_queue_len is not None:
            self.renam_queue_len = renam_queue_len
        if flush_iops is not None:
            self.flush_iops = flush_iops
        if flush_bandwidth is not None:
            self.flush_bandwidth = flush_bandwidth
        if flush_iotime is not None:
            self.flush_iotime = flush_iotime
        if flush_max_time is not None:
            self.flush_max_time = flush_max_time
        if flush_queue_len is not None:
            self.flush_queue_len = flush_queue_len
        if lock_iops is not None:
            self.lock_iops = lock_iops
        if lock_bandwidth is not None:
            self.lock_bandwidth = lock_bandwidth
        if lock_iotime is not None:
            self.lock_iotime = lock_iotime
        if lock_max_time is not None:
            self.lock_max_time = lock_max_time
        if lock_queue_len is not None:
            self.lock_queue_len = lock_queue_len
        if ulock_iops is not None:
            self.ulock_iops = ulock_iops
        if ulock_bandwidth is not None:
            self.ulock_bandwidth = ulock_bandwidth
        if ulock_iotime is not None:
            self.ulock_iotime = ulock_iotime
        if ulock_max_time is not None:
            self.ulock_max_time = ulock_max_time
        if ulock_queue_len is not None:
            self.ulock_queue_len = ulock_queue_len
        if geta_iops is not None:
            self.geta_iops = geta_iops
        if geta_bandwidth is not None:
            self.geta_bandwidth = geta_bandwidth
        if geta_iotime is not None:
            self.geta_iotime = geta_iotime
        if geta_max_time is not None:
            self.geta_max_time = geta_max_time
        if geta_queue_len is not None:
            self.geta_queue_len = geta_queue_len
        if seta_iops is not None:
            self.seta_iops = seta_iops
        if seta_bandwidth is not None:
            self.seta_bandwidth = seta_bandwidth
        if seta_iotime is not None:
            self.seta_iotime = seta_iotime
        if seta_max_time is not None:
            self.seta_max_time = seta_max_time
        if seta_queue_len is not None:
            self.seta_queue_len = seta_queue_len
        if rddir_iops is not None:
            self.rddir_iops = rddir_iops
        if rddir_bandwidth is not None:
            self.rddir_bandwidth = rddir_bandwidth
        if rddir_iotime is not None:
            self.rddir_iotime = rddir_iotime
        if rddir_max_time is not None:
            self.rddir_max_time = rddir_max_time
        if rddir_queue_len is not None:
            self.rddir_queue_len = rddir_queue_len
        if time is not None:
            self.time = time

    @property
    def rd_iops(self):
        """Gets the rd_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rd_iops

    @rd_iops.setter
    def rd_iops(self, rd_iops):
        """Sets the rd_iops of this InlineResponse200268ResponseUsages.


        :param rd_iops: The rd_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rd_iops = rd_iops

    @property
    def rd_bandwidth(self):
        """Gets the rd_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rd_bandwidth

    @rd_bandwidth.setter
    def rd_bandwidth(self, rd_bandwidth):
        """Sets the rd_bandwidth of this InlineResponse200268ResponseUsages.


        :param rd_bandwidth: The rd_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rd_bandwidth = rd_bandwidth

    @property
    def rd_iotime(self):
        """Gets the rd_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rd_iotime

    @rd_iotime.setter
    def rd_iotime(self, rd_iotime):
        """Sets the rd_iotime of this InlineResponse200268ResponseUsages.


        :param rd_iotime: The rd_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rd_iotime = rd_iotime

    @property
    def rd_max_time(self):
        """Gets the rd_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._rd_max_time

    @rd_max_time.setter
    def rd_max_time(self, rd_max_time):
        """Sets the rd_max_time of this InlineResponse200268ResponseUsages.


        :param rd_max_time: The rd_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._rd_max_time = rd_max_time

    @property
    def rd_queue_len(self):
        """Gets the rd_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._rd_queue_len

    @rd_queue_len.setter
    def rd_queue_len(self, rd_queue_len):
        """Sets the rd_queue_len of this InlineResponse200268ResponseUsages.


        :param rd_queue_len: The rd_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._rd_queue_len = rd_queue_len

    @property
    def wrt_iops(self):
        """Gets the wrt_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._wrt_iops

    @wrt_iops.setter
    def wrt_iops(self, wrt_iops):
        """Sets the wrt_iops of this InlineResponse200268ResponseUsages.


        :param wrt_iops: The wrt_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._wrt_iops = wrt_iops

    @property
    def wrt_bandwidth(self):
        """Gets the wrt_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._wrt_bandwidth

    @wrt_bandwidth.setter
    def wrt_bandwidth(self, wrt_bandwidth):
        """Sets the wrt_bandwidth of this InlineResponse200268ResponseUsages.


        :param wrt_bandwidth: The wrt_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._wrt_bandwidth = wrt_bandwidth

    @property
    def wrt_iotime(self):
        """Gets the wrt_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._wrt_iotime

    @wrt_iotime.setter
    def wrt_iotime(self, wrt_iotime):
        """Sets the wrt_iotime of this InlineResponse200268ResponseUsages.


        :param wrt_iotime: The wrt_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._wrt_iotime = wrt_iotime

    @property
    def wrt_max_time(self):
        """Gets the wrt_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._wrt_max_time

    @wrt_max_time.setter
    def wrt_max_time(self, wrt_max_time):
        """Sets the wrt_max_time of this InlineResponse200268ResponseUsages.


        :param wrt_max_time: The wrt_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._wrt_max_time = wrt_max_time

    @property
    def wrt_queue_len(self):
        """Gets the wrt_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._wrt_queue_len

    @wrt_queue_len.setter
    def wrt_queue_len(self, wrt_queue_len):
        """Sets the wrt_queue_len of this InlineResponse200268ResponseUsages.


        :param wrt_queue_len: The wrt_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._wrt_queue_len = wrt_queue_len

    @property
    def nonrw_iops(self):
        """Gets the nonrw_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._nonrw_iops

    @nonrw_iops.setter
    def nonrw_iops(self, nonrw_iops):
        """Sets the nonrw_iops of this InlineResponse200268ResponseUsages.


        :param nonrw_iops: The nonrw_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._nonrw_iops = nonrw_iops

    @property
    def nonrw_bandwidth(self):
        """Gets the nonrw_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._nonrw_bandwidth

    @nonrw_bandwidth.setter
    def nonrw_bandwidth(self, nonrw_bandwidth):
        """Sets the nonrw_bandwidth of this InlineResponse200268ResponseUsages.


        :param nonrw_bandwidth: The nonrw_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._nonrw_bandwidth = nonrw_bandwidth

    @property
    def nonrw_iotime(self):
        """Gets the nonrw_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._nonrw_iotime

    @nonrw_iotime.setter
    def nonrw_iotime(self, nonrw_iotime):
        """Sets the nonrw_iotime of this InlineResponse200268ResponseUsages.


        :param nonrw_iotime: The nonrw_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._nonrw_iotime = nonrw_iotime

    @property
    def nonrw_max_time(self):
        """Gets the nonrw_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._nonrw_max_time

    @nonrw_max_time.setter
    def nonrw_max_time(self, nonrw_max_time):
        """Sets the nonrw_max_time of this InlineResponse200268ResponseUsages.


        :param nonrw_max_time: The nonrw_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._nonrw_max_time = nonrw_max_time

    @property
    def nonrw_queue_len(self):
        """Gets the nonrw_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._nonrw_queue_len

    @nonrw_queue_len.setter
    def nonrw_queue_len(self, nonrw_queue_len):
        """Sets the nonrw_queue_len of this InlineResponse200268ResponseUsages.


        :param nonrw_queue_len: The nonrw_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._nonrw_queue_len = nonrw_queue_len

    @property
    def xcopy_iops(self):
        """Gets the xcopy_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._xcopy_iops

    @xcopy_iops.setter
    def xcopy_iops(self, xcopy_iops):
        """Sets the xcopy_iops of this InlineResponse200268ResponseUsages.


        :param xcopy_iops: The xcopy_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._xcopy_iops = xcopy_iops

    @property
    def xcopy_bandwidth(self):
        """Gets the xcopy_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._xcopy_bandwidth

    @xcopy_bandwidth.setter
    def xcopy_bandwidth(self, xcopy_bandwidth):
        """Sets the xcopy_bandwidth of this InlineResponse200268ResponseUsages.


        :param xcopy_bandwidth: The xcopy_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._xcopy_bandwidth = xcopy_bandwidth

    @property
    def xcopy_iotime(self):
        """Gets the xcopy_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._xcopy_iotime

    @xcopy_iotime.setter
    def xcopy_iotime(self, xcopy_iotime):
        """Sets the xcopy_iotime of this InlineResponse200268ResponseUsages.


        :param xcopy_iotime: The xcopy_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._xcopy_iotime = xcopy_iotime

    @property
    def xcopy_max_time(self):
        """Gets the xcopy_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._xcopy_max_time

    @xcopy_max_time.setter
    def xcopy_max_time(self, xcopy_max_time):
        """Sets the xcopy_max_time of this InlineResponse200268ResponseUsages.


        :param xcopy_max_time: The xcopy_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._xcopy_max_time = xcopy_max_time

    @property
    def xcopy_queue_len(self):
        """Gets the xcopy_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._xcopy_queue_len

    @xcopy_queue_len.setter
    def xcopy_queue_len(self, xcopy_queue_len):
        """Sets the xcopy_queue_len of this InlineResponse200268ResponseUsages.


        :param xcopy_queue_len: The xcopy_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._xcopy_queue_len = xcopy_queue_len

    @property
    def other_iops(self):
        """Gets the other_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._other_iops

    @other_iops.setter
    def other_iops(self, other_iops):
        """Sets the other_iops of this InlineResponse200268ResponseUsages.


        :param other_iops: The other_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._other_iops = other_iops

    @property
    def other_bandwidth(self):
        """Gets the other_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._other_bandwidth

    @other_bandwidth.setter
    def other_bandwidth(self, other_bandwidth):
        """Sets the other_bandwidth of this InlineResponse200268ResponseUsages.


        :param other_bandwidth: The other_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._other_bandwidth = other_bandwidth

    @property
    def other_iotime(self):
        """Gets the other_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._other_iotime

    @other_iotime.setter
    def other_iotime(self, other_iotime):
        """Sets the other_iotime of this InlineResponse200268ResponseUsages.


        :param other_iotime: The other_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._other_iotime = other_iotime

    @property
    def other_max_time(self):
        """Gets the other_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._other_max_time

    @other_max_time.setter
    def other_max_time(self, other_max_time):
        """Sets the other_max_time of this InlineResponse200268ResponseUsages.


        :param other_max_time: The other_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._other_max_time = other_max_time

    @property
    def other_queue_len(self):
        """Gets the other_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._other_queue_len

    @other_queue_len.setter
    def other_queue_len(self, other_queue_len):
        """Sets the other_queue_len of this InlineResponse200268ResponseUsages.


        :param other_queue_len: The other_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._other_queue_len = other_queue_len

    @property
    def creat_iops(self):
        """Gets the creat_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._creat_iops

    @creat_iops.setter
    def creat_iops(self, creat_iops):
        """Sets the creat_iops of this InlineResponse200268ResponseUsages.


        :param creat_iops: The creat_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._creat_iops = creat_iops

    @property
    def creat_bandwidth(self):
        """Gets the creat_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._creat_bandwidth

    @creat_bandwidth.setter
    def creat_bandwidth(self, creat_bandwidth):
        """Sets the creat_bandwidth of this InlineResponse200268ResponseUsages.


        :param creat_bandwidth: The creat_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._creat_bandwidth = creat_bandwidth

    @property
    def creat_iotime(self):
        """Gets the creat_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._creat_iotime

    @creat_iotime.setter
    def creat_iotime(self, creat_iotime):
        """Sets the creat_iotime of this InlineResponse200268ResponseUsages.


        :param creat_iotime: The creat_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._creat_iotime = creat_iotime

    @property
    def creat_max_time(self):
        """Gets the creat_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._creat_max_time

    @creat_max_time.setter
    def creat_max_time(self, creat_max_time):
        """Sets the creat_max_time of this InlineResponse200268ResponseUsages.


        :param creat_max_time: The creat_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._creat_max_time = creat_max_time

    @property
    def creat_queue_len(self):
        """Gets the creat_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._creat_queue_len

    @creat_queue_len.setter
    def creat_queue_len(self, creat_queue_len):
        """Sets the creat_queue_len of this InlineResponse200268ResponseUsages.


        :param creat_queue_len: The creat_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._creat_queue_len = creat_queue_len

    @property
    def delet_iops(self):
        """Gets the delet_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._delet_iops

    @delet_iops.setter
    def delet_iops(self, delet_iops):
        """Sets the delet_iops of this InlineResponse200268ResponseUsages.


        :param delet_iops: The delet_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._delet_iops = delet_iops

    @property
    def delet_bandwidth(self):
        """Gets the delet_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._delet_bandwidth

    @delet_bandwidth.setter
    def delet_bandwidth(self, delet_bandwidth):
        """Sets the delet_bandwidth of this InlineResponse200268ResponseUsages.


        :param delet_bandwidth: The delet_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._delet_bandwidth = delet_bandwidth

    @property
    def delet_iotime(self):
        """Gets the delet_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._delet_iotime

    @delet_iotime.setter
    def delet_iotime(self, delet_iotime):
        """Sets the delet_iotime of this InlineResponse200268ResponseUsages.


        :param delet_iotime: The delet_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._delet_iotime = delet_iotime

    @property
    def delet_max_time(self):
        """Gets the delet_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._delet_max_time

    @delet_max_time.setter
    def delet_max_time(self, delet_max_time):
        """Sets the delet_max_time of this InlineResponse200268ResponseUsages.


        :param delet_max_time: The delet_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._delet_max_time = delet_max_time

    @property
    def delet_queue_len(self):
        """Gets the delet_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._delet_queue_len

    @delet_queue_len.setter
    def delet_queue_len(self, delet_queue_len):
        """Sets the delet_queue_len of this InlineResponse200268ResponseUsages.


        :param delet_queue_len: The delet_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._delet_queue_len = delet_queue_len

    @property
    def renam_iops(self):
        """Gets the renam_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._renam_iops

    @renam_iops.setter
    def renam_iops(self, renam_iops):
        """Sets the renam_iops of this InlineResponse200268ResponseUsages.


        :param renam_iops: The renam_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._renam_iops = renam_iops

    @property
    def renam_bandwidth(self):
        """Gets the renam_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._renam_bandwidth

    @renam_bandwidth.setter
    def renam_bandwidth(self, renam_bandwidth):
        """Sets the renam_bandwidth of this InlineResponse200268ResponseUsages.


        :param renam_bandwidth: The renam_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._renam_bandwidth = renam_bandwidth

    @property
    def renam_iotime(self):
        """Gets the renam_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._renam_iotime

    @renam_iotime.setter
    def renam_iotime(self, renam_iotime):
        """Sets the renam_iotime of this InlineResponse200268ResponseUsages.


        :param renam_iotime: The renam_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._renam_iotime = renam_iotime

    @property
    def renam_max_time(self):
        """Gets the renam_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._renam_max_time

    @renam_max_time.setter
    def renam_max_time(self, renam_max_time):
        """Sets the renam_max_time of this InlineResponse200268ResponseUsages.


        :param renam_max_time: The renam_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._renam_max_time = renam_max_time

    @property
    def renam_queue_len(self):
        """Gets the renam_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._renam_queue_len

    @renam_queue_len.setter
    def renam_queue_len(self, renam_queue_len):
        """Sets the renam_queue_len of this InlineResponse200268ResponseUsages.


        :param renam_queue_len: The renam_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._renam_queue_len = renam_queue_len

    @property
    def flush_iops(self):
        """Gets the flush_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._flush_iops

    @flush_iops.setter
    def flush_iops(self, flush_iops):
        """Sets the flush_iops of this InlineResponse200268ResponseUsages.


        :param flush_iops: The flush_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._flush_iops = flush_iops

    @property
    def flush_bandwidth(self):
        """Gets the flush_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._flush_bandwidth

    @flush_bandwidth.setter
    def flush_bandwidth(self, flush_bandwidth):
        """Sets the flush_bandwidth of this InlineResponse200268ResponseUsages.


        :param flush_bandwidth: The flush_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._flush_bandwidth = flush_bandwidth

    @property
    def flush_iotime(self):
        """Gets the flush_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._flush_iotime

    @flush_iotime.setter
    def flush_iotime(self, flush_iotime):
        """Sets the flush_iotime of this InlineResponse200268ResponseUsages.


        :param flush_iotime: The flush_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._flush_iotime = flush_iotime

    @property
    def flush_max_time(self):
        """Gets the flush_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._flush_max_time

    @flush_max_time.setter
    def flush_max_time(self, flush_max_time):
        """Sets the flush_max_time of this InlineResponse200268ResponseUsages.


        :param flush_max_time: The flush_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._flush_max_time = flush_max_time

    @property
    def flush_queue_len(self):
        """Gets the flush_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._flush_queue_len

    @flush_queue_len.setter
    def flush_queue_len(self, flush_queue_len):
        """Sets the flush_queue_len of this InlineResponse200268ResponseUsages.


        :param flush_queue_len: The flush_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._flush_queue_len = flush_queue_len

    @property
    def lock_iops(self):
        """Gets the lock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._lock_iops

    @lock_iops.setter
    def lock_iops(self, lock_iops):
        """Sets the lock_iops of this InlineResponse200268ResponseUsages.


        :param lock_iops: The lock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._lock_iops = lock_iops

    @property
    def lock_bandwidth(self):
        """Gets the lock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._lock_bandwidth

    @lock_bandwidth.setter
    def lock_bandwidth(self, lock_bandwidth):
        """Sets the lock_bandwidth of this InlineResponse200268ResponseUsages.


        :param lock_bandwidth: The lock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._lock_bandwidth = lock_bandwidth

    @property
    def lock_iotime(self):
        """Gets the lock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._lock_iotime

    @lock_iotime.setter
    def lock_iotime(self, lock_iotime):
        """Sets the lock_iotime of this InlineResponse200268ResponseUsages.


        :param lock_iotime: The lock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._lock_iotime = lock_iotime

    @property
    def lock_max_time(self):
        """Gets the lock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._lock_max_time

    @lock_max_time.setter
    def lock_max_time(self, lock_max_time):
        """Sets the lock_max_time of this InlineResponse200268ResponseUsages.


        :param lock_max_time: The lock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._lock_max_time = lock_max_time

    @property
    def lock_queue_len(self):
        """Gets the lock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._lock_queue_len

    @lock_queue_len.setter
    def lock_queue_len(self, lock_queue_len):
        """Sets the lock_queue_len of this InlineResponse200268ResponseUsages.


        :param lock_queue_len: The lock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._lock_queue_len = lock_queue_len

    @property
    def ulock_iops(self):
        """Gets the ulock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._ulock_iops

    @ulock_iops.setter
    def ulock_iops(self, ulock_iops):
        """Sets the ulock_iops of this InlineResponse200268ResponseUsages.


        :param ulock_iops: The ulock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._ulock_iops = ulock_iops

    @property
    def ulock_bandwidth(self):
        """Gets the ulock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._ulock_bandwidth

    @ulock_bandwidth.setter
    def ulock_bandwidth(self, ulock_bandwidth):
        """Sets the ulock_bandwidth of this InlineResponse200268ResponseUsages.


        :param ulock_bandwidth: The ulock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._ulock_bandwidth = ulock_bandwidth

    @property
    def ulock_iotime(self):
        """Gets the ulock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._ulock_iotime

    @ulock_iotime.setter
    def ulock_iotime(self, ulock_iotime):
        """Sets the ulock_iotime of this InlineResponse200268ResponseUsages.


        :param ulock_iotime: The ulock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._ulock_iotime = ulock_iotime

    @property
    def ulock_max_time(self):
        """Gets the ulock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._ulock_max_time

    @ulock_max_time.setter
    def ulock_max_time(self, ulock_max_time):
        """Sets the ulock_max_time of this InlineResponse200268ResponseUsages.


        :param ulock_max_time: The ulock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._ulock_max_time = ulock_max_time

    @property
    def ulock_queue_len(self):
        """Gets the ulock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._ulock_queue_len

    @ulock_queue_len.setter
    def ulock_queue_len(self, ulock_queue_len):
        """Sets the ulock_queue_len of this InlineResponse200268ResponseUsages.


        :param ulock_queue_len: The ulock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._ulock_queue_len = ulock_queue_len

    @property
    def geta_iops(self):
        """Gets the geta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._geta_iops

    @geta_iops.setter
    def geta_iops(self, geta_iops):
        """Sets the geta_iops of this InlineResponse200268ResponseUsages.


        :param geta_iops: The geta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._geta_iops = geta_iops

    @property
    def geta_bandwidth(self):
        """Gets the geta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._geta_bandwidth

    @geta_bandwidth.setter
    def geta_bandwidth(self, geta_bandwidth):
        """Sets the geta_bandwidth of this InlineResponse200268ResponseUsages.


        :param geta_bandwidth: The geta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._geta_bandwidth = geta_bandwidth

    @property
    def geta_iotime(self):
        """Gets the geta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._geta_iotime

    @geta_iotime.setter
    def geta_iotime(self, geta_iotime):
        """Sets the geta_iotime of this InlineResponse200268ResponseUsages.


        :param geta_iotime: The geta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._geta_iotime = geta_iotime

    @property
    def geta_max_time(self):
        """Gets the geta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._geta_max_time

    @geta_max_time.setter
    def geta_max_time(self, geta_max_time):
        """Sets the geta_max_time of this InlineResponse200268ResponseUsages.


        :param geta_max_time: The geta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._geta_max_time = geta_max_time

    @property
    def geta_queue_len(self):
        """Gets the geta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._geta_queue_len

    @geta_queue_len.setter
    def geta_queue_len(self, geta_queue_len):
        """Sets the geta_queue_len of this InlineResponse200268ResponseUsages.


        :param geta_queue_len: The geta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._geta_queue_len = geta_queue_len

    @property
    def seta_iops(self):
        """Gets the seta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._seta_iops

    @seta_iops.setter
    def seta_iops(self, seta_iops):
        """Sets the seta_iops of this InlineResponse200268ResponseUsages.


        :param seta_iops: The seta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._seta_iops = seta_iops

    @property
    def seta_bandwidth(self):
        """Gets the seta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._seta_bandwidth

    @seta_bandwidth.setter
    def seta_bandwidth(self, seta_bandwidth):
        """Sets the seta_bandwidth of this InlineResponse200268ResponseUsages.


        :param seta_bandwidth: The seta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._seta_bandwidth = seta_bandwidth

    @property
    def seta_iotime(self):
        """Gets the seta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._seta_iotime

    @seta_iotime.setter
    def seta_iotime(self, seta_iotime):
        """Sets the seta_iotime of this InlineResponse200268ResponseUsages.


        :param seta_iotime: The seta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._seta_iotime = seta_iotime

    @property
    def seta_max_time(self):
        """Gets the seta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._seta_max_time

    @seta_max_time.setter
    def seta_max_time(self, seta_max_time):
        """Sets the seta_max_time of this InlineResponse200268ResponseUsages.


        :param seta_max_time: The seta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._seta_max_time = seta_max_time

    @property
    def seta_queue_len(self):
        """Gets the seta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._seta_queue_len

    @seta_queue_len.setter
    def seta_queue_len(self, seta_queue_len):
        """Sets the seta_queue_len of this InlineResponse200268ResponseUsages.


        :param seta_queue_len: The seta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._seta_queue_len = seta_queue_len

    @property
    def rddir_iops(self):
        """Gets the rddir_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rddir_iops

    @rddir_iops.setter
    def rddir_iops(self, rddir_iops):
        """Sets the rddir_iops of this InlineResponse200268ResponseUsages.


        :param rddir_iops: The rddir_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rddir_iops = rddir_iops

    @property
    def rddir_bandwidth(self):
        """Gets the rddir_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rddir_bandwidth

    @rddir_bandwidth.setter
    def rddir_bandwidth(self, rddir_bandwidth):
        """Sets the rddir_bandwidth of this InlineResponse200268ResponseUsages.


        :param rddir_bandwidth: The rddir_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rddir_bandwidth = rddir_bandwidth

    @property
    def rddir_iotime(self):
        """Gets the rddir_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rddir_iotime

    @rddir_iotime.setter
    def rddir_iotime(self, rddir_iotime):
        """Sets the rddir_iotime of this InlineResponse200268ResponseUsages.


        :param rddir_iotime: The rddir_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rddir_iotime = rddir_iotime

    @property
    def rddir_max_time(self):
        """Gets the rddir_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._rddir_max_time

    @rddir_max_time.setter
    def rddir_max_time(self, rddir_max_time):
        """Sets the rddir_max_time of this InlineResponse200268ResponseUsages.


        :param rddir_max_time: The rddir_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._rddir_max_time = rddir_max_time

    @property
    def rddir_queue_len(self):
        """Gets the rddir_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._rddir_queue_len

    @rddir_queue_len.setter
    def rddir_queue_len(self, rddir_queue_len):
        """Sets the rddir_queue_len of this InlineResponse200268ResponseUsages.


        :param rddir_queue_len: The rddir_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._rddir_queue_len = rddir_queue_len

    @property
    def time(self):
        """Gets the time of this InlineResponse200268ResponseUsages.  # noqa: E501

        the time to which the stats relate to  # noqa: E501

        :return: The time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this InlineResponse200268ResponseUsages.

        the time to which the stats relate to  # noqa: E501

        :param time: The time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: str
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200268ResponseUsages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200268ResponseUsages):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200268ResponseUsages):
            return True

        return self.to_dict() != other.to_dict()
