# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20029ResponseTarget(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'job_count': 'int',
        'state': 'str',
        'endpoint': 'str',
        'access': 'str',
        'secret': 'str',
        'region': 'str',
        'network': 'str',
        'type': 'str',
        'ext_name': 'str',
        'display_name': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'job_count': 'job_count',
        'state': 'state',
        'endpoint': 'endpoint',
        'access': 'access',
        'secret': 'secret',
        'region': 'region',
        'network': 'network',
        'type': 'type',
        'ext_name': 'ext_name',
        'display_name': 'display_name',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, id=None, job_count=None, state=None, endpoint=None, access=None, secret=None, region=None, network=None, type=None, ext_name=None, display_name=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20029ResponseTarget - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._job_count = None
        self._state = None
        self._endpoint = None
        self._access = None
        self._secret = None
        self._region = None
        self._network = None
        self._type = None
        self._ext_name = None
        self._display_name = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if job_count is not None:
            self.job_count = job_count
        if state is not None:
            self.state = state
        if endpoint is not None:
            self.endpoint = endpoint
        if access is not None:
            self.access = access
        if secret is not None:
            self.secret = secret
        if region is not None:
            self.region = region
        if network is not None:
            self.network = network
        if type is not None:
            self.type = type
        if ext_name is not None:
            self.ext_name = ext_name
        if display_name is not None:
            self.display_name = display_name
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def id(self):
        """Gets the id of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The id of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20029ResponseTarget.


        :param id: The id of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def job_count(self):
        """Gets the job_count of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The job_count of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: int
        """
        return self._job_count

    @job_count.setter
    def job_count(self, job_count):
        """Sets the job_count of this InlineResponse20029ResponseTarget.


        :param job_count: The job_count of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: int
        """

        self._job_count = job_count

    @property
    def state(self):
        """Gets the state of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The state of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse20029ResponseTarget.


        :param state: The state of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def endpoint(self):
        """Gets the endpoint of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The endpoint of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this InlineResponse20029ResponseTarget.


        :param endpoint: The endpoint of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def access(self):
        """Gets the access of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The access of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this InlineResponse20029ResponseTarget.


        :param access: The access of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._access = access

    @property
    def secret(self):
        """Gets the secret of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The secret of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this InlineResponse20029ResponseTarget.


        :param secret: The secret of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def region(self):
        """Gets the region of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The region of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this InlineResponse20029ResponseTarget.


        :param region: The region of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def network(self):
        """Gets the network of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The network of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this InlineResponse20029ResponseTarget.


        :param network: The network of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._network = network

    @property
    def type(self):
        """Gets the type of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The type of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse20029ResponseTarget.


        :param type: The type of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def ext_name(self):
        """Gets the ext_name of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The ext_name of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._ext_name

    @ext_name.setter
    def ext_name(self, ext_name):
        """Sets the ext_name of this InlineResponse20029ResponseTarget.


        :param ext_name: The ext_name of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._ext_name = ext_name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The display_name of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20029ResponseTarget.


        :param display_name: The display_name of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The created_at of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20029ResponseTarget.


        :param created_at: The created_at of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The modified_at of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20029ResponseTarget.


        :param modified_at: The modified_at of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20029ResponseTarget, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20029ResponseTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20029ResponseTarget):
            return True

        return self.to_dict() != other.to_dict()
